@@ -16,7 +16,7 @@ die() {
 
 
 DIRNAME="../lib/"
-CONSOLEJAR="$DIRNAME/pdfsam-console-1.1.5e.jar"
+CONSOLEJAR="$DIRNAME/@CONSOLE_JAR_NAME.jar"
 
 # Setup the classpath
 if [ ! -f "$CONSOLEJAR" ]; then
@@ -33,7 +33,7 @@ if [ "x$JAVA" = "x" ]; then
     fi
 fi
 
-# Setup JBoss sepecific properties
+# Setup sepecific properties
 JAVA_OPTS="-Dlog4j.configuration=console-log4j.xml"
 
 # Display our environment
@@ -41,6 +41,11 @@ echo "========================================================================="
 echo ""
 echo " pdfsam console"
 echo ""
+echo " available properties:"
+echo " pdfsam.log.console.level"
+echo " pdfsam.log.file.level"
+echo " pdfsam.log.file.filename"
+echo ""
 echo "  JAVA: $JAVA"
 echo ""
 echo "  JAVA_OPTS: $JAVA_OPTS"
