@@ -504,9 +504,8 @@ public class JPdfSelectionPanel extends JPanel {
      * @param button
      */
     private void addButtonToButtonPanel(JButton button){
-    	button.setMinimumSize(new Dimension(90, 25));
-    	button.setMaximumSize(new Dimension(100, 25));
-    	button.setPreferredSize(new Dimension(95, 25));
+    	button.setMinimumSize(new Dimension(110, 25));
+    	button.setMaximumSize(new Dimension(160, 25));
     	buttonPanel.add(button);
 		buttonPanel.add(Box.createRigidArea(new Dimension(0,5)));
     }
@@ -690,4 +689,12 @@ public class JPdfSelectionPanel extends JPanel {
     		popupMenu.add(menuItem);
     	}
     }
+    
+    /**
+     * If true, the selection table default renderer will show a tooltip message when the document is not opened with full permissions 
+     * @param required
+     */
+    public void setFullAccessRequired(boolean required){
+    	mainTable.setDefaultRenderer(String.class, new JPdfSelectionTableRenderer(required));
+    }
 }
