@@ -16,11 +16,13 @@
 
 package org.pdfsam.plugin.merge.GUI;
 
-import java.awt.Color;
 import java.awt.Component;
 import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.FocusTraversalPolicy;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.beans.PropertyChangeEvent;
@@ -28,7 +30,9 @@ import java.beans.PropertyChangeListener;
 import java.io.File;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.regex.Pattern;
 
+import javax.swing.BorderFactory;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
 import javax.swing.JFileChooser;
@@ -37,14 +41,15 @@ import javax.swing.JOptionPane;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 import javax.swing.SpringLayout;
-import javax.swing.border.MatteBorder;
 
 import org.apache.log4j.Logger;
 import org.dom4j.Element;
 import org.dom4j.Node;
 import org.pdfsam.console.business.dto.commands.AbstractParsedCommand;
 import org.pdfsam.console.business.dto.commands.ConcatParsedCommand;
+import org.pdfsam.console.business.parser.validators.ConcatCmdValidator;
 import org.pdfsam.guiclient.business.listeners.EnterDoClickListener;
+import org.pdfsam.guiclient.commons.business.SoundPlayer;
 import org.pdfsam.guiclient.commons.business.WorkExecutor;
 import org.pdfsam.guiclient.commons.business.WorkThread;
 import org.pdfsam.guiclient.commons.business.listeners.CompressCheckBoxItemListener;
@@ -76,7 +81,6 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
 	private static final Logger log = Logger.getLogger(MergeMainGUI.class.getPackage().getName());
 
     private JTextField destinationTextField = CommonComponentsFactory.getInstance().createTextField(CommonComponentsFactory.DESTINATION_TEXT_FIELD_TYPE);
-    private SpringLayout layoutMergePanel;
     private JFileChooser browseDestFileChooser;
     private SpringLayout layoutDestinationPanel;
     private JPanel destinationPanel = new JPanel();
@@ -86,10 +90,9 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
     private JHelpLabel destinationHelpLabel;
     private Configuration config;
     private JCheckBox mergeTypeCheck = new JCheckBox();
-    private final JLabel optionLabel = new JLabel();
 	private JPdfVersionCombo versionCombo = new JPdfVersionCombo();
 	private JPdfSelectionPanel selectionPanel = new JPdfSelectionPanel(JPdfSelectionPanel.UNLIMTED_SELECTABLE_FILE_NUMBER, AbstractPdfSelectionTableModel.MAX_COLUMNS_NUMBER);
-
+	private JPanel topPanel = new JPanel();
 
 	//button
     private final JButton browseDestButton = CommonComponentsFactory.getInstance().createButton(CommonComponentsFactory.BROWSE_BUTTON_TYPE);       
@@ -105,11 +108,10 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
    
 //focus policy 
     private final MergeFocusPolicy mergeFocusPolicy = new MergeFocusPolicy();
-    private final JLabel destinationLabel = new JLabel();
 	private final JLabel outputVersionLabel = CommonComponentsFactory.getInstance().createLabel(CommonComponentsFactory.PDF_VERSION_LABEL);	
 
     private static final String PLUGIN_AUTHOR = "Andrea Vacondio";
-    private static final String PLUGIN_VERSION = "0.6.7";
+    private static final String PLUGIN_VERSION = "0.7.0";
 	private static final String ALL_STRING = "All";
 	
     /**
@@ -128,11 +130,21 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
     	config = Configuration.getInstance();
         setPanelIcon("/images/merge.png");
         setPreferredSize(new Dimension(500,550));
+		
+        setLayout(new GridBagLayout());        
+   
+        topPanel.setLayout(new GridBagLayout());
+        GridBagConstraints topConst = new GridBagConstraints();
+        topConst.fill = GridBagConstraints.BOTH;
+        topConst.ipady = 5;
+        topConst.weightx = 1.0;
+        topConst.weighty = 1.0;
+        topConst.gridwidth = 3;
+        topConst.gridheight = 2;
+        topConst.gridx = 0;
+        topConst.gridy = 0;
+		topPanel.add(selectionPanel, topConst);
         
-        layoutMergePanel = new SpringLayout();
-        setLayout(layoutMergePanel);
-        
-        add(selectionPanel);
         selectionPanel.addPropertyChangeListener(this);      
        
 //END_BROWSE_FILE_CHOOSER        
@@ -140,13 +152,19 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
 //      OPTION_PANEL
         layoutOptionPanel = new SpringLayout();
         optionPanel.setLayout(layoutOptionPanel);
-        optionPanel.setBorder(new MatteBorder(1, 1, 1, 1, Color.LIGHT_GRAY));
-        add(optionPanel);
+        optionPanel.setBorder(BorderFactory.createTitledBorder(GettextResource.gettext(config.getI18nResourceBundle(),"Merge options")));
+        optionPanel.setMinimumSize(new Dimension(50,50));
+        optionPanel.setPreferredSize(new Dimension(50,60));
+        
+        topConst.fill = GridBagConstraints.HORIZONTAL;
+        topConst.weightx = 0.0;
+        topConst.weighty = 0.0;
+        topConst.gridwidth = 3;
+        topConst.gridheight = 1;
+        topConst.gridx = 0;
+        topConst.gridy = 2;
+        topPanel.add(optionPanel, topConst);                
         
-//END_OPTION_PANEL 
-        optionLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Merge options:"));
-        add(optionLabel);
-
         mergeTypeCheck.setText(GettextResource.gettext(config.getI18nResourceBundle(),"PDF documents contain forms"));
         mergeTypeCheck.setSelected(false);
         optionPanel.add(mergeTypeCheck);     
@@ -158,18 +176,40 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
     		"<br><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Note")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Setting this option the documents will be completely loaded in memory")+".</li>" +
     		"</ul></body></html>";
 	    mergeTypeHelpLabel = new JHelpLabel(helpText, true);
-	    optionPanel.add(mergeTypeHelpLabel);       
+	    optionPanel.add(mergeTypeHelpLabel); 
+//END_OPTION_PANEL 	   
+	    
+	    GridBagConstraints c = new GridBagConstraints();
+        c.fill = GridBagConstraints.BOTH;
+        c.ipady = 5;
+        c.weightx = 1.0;
+        c.weighty = 1.0;
+        c.gridwidth = 3;
+        c.gridx = 0;
+        c.gridy = 0;
+        c.insets = new Insets(0, 0, 10, 0);
+		add(topPanel, c);
+		
 //DESTINATION_PANEL
         layoutDestinationPanel = new SpringLayout();
         destinationPanel.setLayout(layoutDestinationPanel);
-        destinationPanel.setBorder(new MatteBorder(1, 1, 1, 1, Color.LIGHT_GRAY));
-        add(destinationPanel);
+        destinationPanel.setBorder(BorderFactory.createTitledBorder(GettextResource.gettext(config.getI18nResourceBundle(),"Destination output file")));
+		destinationPanel.setPreferredSize(new Dimension(200, 160));
+		destinationPanel.setMinimumSize(new Dimension(160, 150));
+
+		
+		c.fill = GridBagConstraints.HORIZONTAL;
+	    c.ipady = 5;
+	    c.weightx = 1.0;
+	    c.weighty = 0.0;
+	    c.gridwidth = 3;
+	    c.gridx = 0;
+	    c.gridy = 1;	
+	    c.insets = new Insets(0, 0, 0, 0);
+		add(destinationPanel, c);
 //END_DESTINATION_PANEL   
 
         destinationPanel.add(destinationTextField);
-        
-        destinationLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Destination output file:"));
-        add(destinationLabel);
 //BROWSE_BUTTON        
         browseDestButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
@@ -177,9 +217,11 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
             		 browseDestFileChooser = new JFileChooser(Configuration.getInstance().getDefaultWorkingDir());
             		 browseDestFileChooser.setFileFilter(new PdfFilter());
             	}
-                int retVal = browseDestFileChooser.showOpenDialog(browseDestButton.getParent());
-                File chosenFile = null;                
-                if (retVal == JFileChooser.APPROVE_OPTION){
+                File chosenFile = null;
+                if(destinationTextField.getText().length()>0){
+                	browseDestFileChooser.setCurrentDirectory(new File(destinationTextField.getText()));
+                }
+                if (browseDestFileChooser.showOpenDialog(browseDestButton.getParent()) == JFileChooser.APPROVE_OPTION){
                 	chosenFile = browseDestFileChooser.getSelectedFile();
                 }
                 //write the destination in text field
@@ -197,8 +239,6 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
         destinationPanel.add(browseDestButton);
 //END_BROWSE_BUTTON
 //CHECK_BOX
-        overwriteCheckbox.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Overwrite if already exists"));
-        overwriteCheckbox.setSelected(true);
         destinationPanel.add(overwriteCheckbox);
         
         outputCompressedCheck.addItemListener(new CompressCheckBoxItemListener(versionCombo));
@@ -230,11 +270,11 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
                 final LinkedList args = new LinkedList();  
                 try{             	
                 	PdfSelectionTableItem[] items = selectionPanel.getTableRows();
-                	if(items != null && items.length >= 1){					
-		                args.add("-"+ConcatParsedCommand.O_ARG);
+                	if(items != null && items.length >= 1){
+                		String destination = "";
 	                    //if no extension given
 	                    if ((destinationTextField.getText().length() > 0) && !(destinationTextField.getText().matches(PDF_EXTENSION_REGEXP))){
-	                        destinationTextField.setText(destinationTextField.getText()+".pdf");
+	                        destinationTextField.setText(destinationTextField.getText()+"."+PDF_EXTENSION);
 	                    }                    
 	                    if(destinationTextField.getText().length()>0){
 	                    	File destinationDir = new File(destinationTextField.getText());
@@ -262,39 +302,46 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
 	                    		}
 	                    	}
 	                    }
-	                    args.add(destinationTextField.getText());
+	                    
+	                    destination = destinationTextField.getText();
+						
+						//check if the file already exists and the user didn't select to overwrite
+						File destFile = (destination!=null)? new File(destination):null;
+						if(destFile!=null && destFile.exists() && !overwriteCheckbox.isSelected()){
+							int chosenOpt = DialogUtility.askForOverwriteOutputFileDialog(getParent(),destFile.getName());
+                			if(JOptionPane.YES_OPTION == chosenOpt){
+                				overwriteCheckbox.setSelected(true);
+		        			}else if(JOptionPane.CANCEL_OPTION == chosenOpt){
+		        				return;
+		        			}
+						}
+						
+		                args.add("-"+ConcatParsedCommand.O_ARG);
+	                    args.add(destination);
 	                    
 	                    PdfSelectionTableItem item = null;    
 	                	String pageSelectionString = "";
 	                	for (int i = 0; i < items.length; i++){
 							item = items[i];
 							String pageSelection = (item.getPageSelection()!=null && item.getPageSelection().length()>0)?item.getPageSelection():ALL_STRING;
-							if(pageSelection.trim().length()>0 && pageSelection.indexOf(",") != 0){
-	                            String[] selectionsArray = pageSelection.split(",");
-	                            for(int j = 0; j<selectionsArray.length; j++){
-	                                String tmpString = selectionsArray[j].trim();
-	                                if((tmpString != null)&&(!tmpString.equals(""))){
-		                                args.add("-"+ConcatParsedCommand.F_ARG);
-		                                String f = item.getInputFile().getAbsolutePath();
-		        						if((item.getPassword()) != null && (item.getPassword()).length()>0){
-		        							log.debug(GettextResource.gettext(config.getI18nResourceBundle(),"Found a password for input file."));
-		        							f +=":"+item.getPassword();
-		        						}
-		        						args.add(f);
-		                                pageSelectionString += (tmpString.matches("[\\d]+"))? tmpString+"-"+tmpString+":" : tmpString+":";
-	                                }                                
-	                            }
-	                        
-	                        }else{
-	                        	args.add("-"+ConcatParsedCommand.F_ARG);
-	                            String f = item.getInputFile().getAbsolutePath();
-	    						if((item.getPassword()) != null && (item.getPassword()).length()>0){
-	    							log.debug(GettextResource.gettext(config.getI18nResourceBundle(),"Found a password for input file."));
-	    							f +=":"+item.getPassword();
-	    						}
-	    						args.add(f);
-	                            pageSelectionString += (pageSelection.matches("[\\d]+"))? pageSelection+"-"+pageSelection+":" : pageSelection+":";
-	                        }						
+							//add ":" at the end if necessary
+							if(!pageSelection.endsWith(":")){
+								pageSelection += ":";
+							}
+							Pattern p = Pattern.compile(ConcatCmdValidator.SELECTION_REGEXP, Pattern.CASE_INSENSITIVE);
+							if (!(p.matcher(pageSelection).matches())) {
+								DialogUtility.errorValidatingBounds(getParent(), pageSelection);
+								return;
+							} else {
+								args.add("-" + ConcatParsedCommand.F_ARG);
+								String f = item.getInputFile().getAbsolutePath();
+								if ((item.getPassword()) != null && (item.getPassword()).length() > 0) {
+									log.debug(GettextResource.gettext(config.getI18nResourceBundle(),"Found a password for input file."));
+									f += ":" + item.getPassword();
+								}
+								args.add(f);
+								pageSelectionString += pageSelection;
+							}	                        					
 						}
 						                    
 	                    args.add("-"+ConcatParsedCommand.U_ARG);
@@ -319,11 +366,24 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
 					}
                 }catch(Exception ex){    
                 	log.error(GettextResource.gettext(config.getI18nResourceBundle(),"Error: "), ex);
+                	SoundPlayer.getInstance().playErrorSound();
                 }    
             }
         });
 	    runButton.setToolTipText(GettextResource.gettext(config.getI18nResourceBundle(),"Execute pdf merge"));
-        add(runButton);
+	    runButton.setSize(new Dimension(88,25));
+        
+        c.fill = GridBagConstraints.NONE;
+	    c.ipadx = 5;
+	    c.weightx = 0.0;
+	    c.weighty = 0.0;
+	    c.anchor = GridBagConstraints.LAST_LINE_END;
+	    c.gridwidth = 1;
+	    c.gridx = 2;
+	    c.gridy = 2;
+	    c.insets = new Insets(10,10,10,10); 
+        add(runButton, c);
+        
 //END_RUN_BUTTON
 //KEY_LISTENER
         runButton.addKeyListener(runEnterKeyListener);
@@ -343,32 +403,14 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
      *
      */
     private void setLayout(){
-    	layoutMergePanel.putConstraint(SpringLayout.SOUTH, selectionPanel, 250, SpringLayout.NORTH, this);
-    	layoutMergePanel.putConstraint(SpringLayout.EAST, selectionPanel, -5, SpringLayout.EAST, this);
-		layoutMergePanel.putConstraint(SpringLayout.NORTH, selectionPanel, 5, SpringLayout.NORTH, this);
-		layoutMergePanel.putConstraint(SpringLayout.WEST, selectionPanel, 5, SpringLayout.WEST, this);
-        
-        layoutMergePanel.putConstraint(SpringLayout.SOUTH, optionPanel, 50, SpringLayout.NORTH, optionPanel);
-        layoutMergePanel.putConstraint(SpringLayout.EAST, optionPanel, -5, SpringLayout.EAST, this);
-        layoutMergePanel.putConstraint(SpringLayout.NORTH, optionPanel, 20, SpringLayout.SOUTH, selectionPanel);
-        layoutMergePanel.putConstraint(SpringLayout.WEST, optionPanel, 0, SpringLayout.WEST, selectionPanel);
-
-        layoutMergePanel.putConstraint(SpringLayout.SOUTH, optionLabel, 0, SpringLayout.NORTH, optionPanel);
-        layoutMergePanel.putConstraint(SpringLayout.WEST, optionLabel, 0, SpringLayout.WEST, optionPanel);
-
         layoutOptionPanel.putConstraint(SpringLayout.SOUTH, mergeTypeCheck, 30, SpringLayout.NORTH, optionPanel);
         layoutOptionPanel.putConstraint(SpringLayout.EAST, mergeTypeCheck, -40, SpringLayout.EAST, optionPanel);
-        layoutOptionPanel.putConstraint(SpringLayout.NORTH, mergeTypeCheck, 5, SpringLayout.NORTH, optionPanel);
+        layoutOptionPanel.putConstraint(SpringLayout.NORTH, mergeTypeCheck, 0, SpringLayout.NORTH, optionPanel);
         layoutOptionPanel.putConstraint(SpringLayout.WEST, mergeTypeCheck, 5, SpringLayout.WEST, optionPanel);
 
         layoutOptionPanel.putConstraint(SpringLayout.SOUTH, mergeTypeHelpLabel, -1, SpringLayout.SOUTH, optionPanel);
         layoutOptionPanel.putConstraint(SpringLayout.EAST, mergeTypeHelpLabel, -1, SpringLayout.EAST, optionPanel);
 
-        layoutMergePanel.putConstraint(SpringLayout.SOUTH, destinationPanel, 120, SpringLayout.NORTH, destinationPanel);
-        layoutMergePanel.putConstraint(SpringLayout.EAST, destinationPanel, 0, SpringLayout.EAST, optionPanel);
-        layoutMergePanel.putConstraint(SpringLayout.NORTH, destinationPanel, 20, SpringLayout.SOUTH, optionPanel);
-        layoutMergePanel.putConstraint(SpringLayout.WEST, destinationPanel, 0, SpringLayout.WEST, selectionPanel);
-        
         layoutDestinationPanel.putConstraint(SpringLayout.EAST, destinationTextField, -105, SpringLayout.EAST, destinationPanel);
         layoutDestinationPanel.putConstraint(SpringLayout.NORTH, destinationTextField, 10, SpringLayout.NORTH, destinationPanel);
         layoutDestinationPanel.putConstraint(SpringLayout.SOUTH, destinationTextField, 30, SpringLayout.NORTH, destinationPanel);
@@ -389,9 +431,6 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
         layoutDestinationPanel.putConstraint(SpringLayout.SOUTH, versionCombo, 0, SpringLayout.SOUTH, outputVersionLabel);
         layoutDestinationPanel.putConstraint(SpringLayout.NORTH, versionCombo, 0, SpringLayout.NORTH, outputVersionLabel);
         layoutDestinationPanel.putConstraint(SpringLayout.WEST, versionCombo, 2, SpringLayout.EAST, outputVersionLabel);
-
-        layoutMergePanel.putConstraint(SpringLayout.SOUTH, destinationLabel, 0, SpringLayout.NORTH, destinationPanel);
-        layoutMergePanel.putConstraint(SpringLayout.WEST, destinationLabel, 0, SpringLayout.WEST, destinationPanel);
         
         layoutDestinationPanel.putConstraint(SpringLayout.SOUTH, browseDestButton, 25, SpringLayout.NORTH, browseDestButton);
         layoutDestinationPanel.putConstraint(SpringLayout.EAST, browseDestButton, -5, SpringLayout.EAST, destinationPanel);
@@ -400,11 +439,7 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
         
         layoutDestinationPanel.putConstraint(SpringLayout.SOUTH, destinationHelpLabel, -1, SpringLayout.SOUTH, destinationPanel);
         layoutDestinationPanel.putConstraint(SpringLayout.EAST, destinationHelpLabel, -1, SpringLayout.EAST, destinationPanel);        
-        
-        layoutMergePanel.putConstraint(SpringLayout.SOUTH, runButton, 25, SpringLayout.NORTH, runButton);
-        layoutMergePanel.putConstraint(SpringLayout.EAST, runButton, -10, SpringLayout.EAST, this);
-        layoutMergePanel.putConstraint(SpringLayout.WEST, runButton, -88, SpringLayout.EAST, runButton);
-        layoutMergePanel.putConstraint(SpringLayout.NORTH, runButton, 10, SpringLayout.SOUTH, destinationPanel);
+
 
     }
        
@@ -584,7 +619,7 @@ public class MergeMainGUI extends AbstractPlugablePanel implements PropertyChang
 				return versionCombo;
 			}
 			else if (aComponent.equals(versionCombo)){
-				return overwriteCheckbox;
+				return outputCompressedCheck;
 			}
 			else if (aComponent.equals(outputCompressedCheck)){
 				return overwriteCheckbox;
